summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/gwcontact.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/groupwise/gwcontact.h')
-rw-r--r--kopete/protocols/groupwise/gwcontact.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kopete/protocols/groupwise/gwcontact.h b/kopete/protocols/groupwise/gwcontact.h
index d3c98a6b..2e81823f 100644
--- a/kopete/protocols/groupwise/gwcontact.h
+++ b/kopete/protocols/groupwise/gwcontact.h
@@ -59,13 +59,13 @@ public:
* Constructor
* @param account The GroupWiseAccount this belongs to.
* @param uniqueName The userId for this contact. May be a DN, in which case it will be converted to dotted format for the contactId and stored.
* @param tqparent The Kopete::MetaContact this contact is part of.
* @param objectId The contact's numeric object ID.
- * @param parentId The ID of this contact's tqparent (folder).
- * @param sequence This contact's sequence number (The position it appears in within its tqparent).
+ * @param parentId The ID of this contact's parent (folder).
+ * @param sequence This contact's sequence number (The position it appears in within its parent).
*/
GroupWiseContact( Kopete::Account* account, const TQString &uniqueName,
- Kopete::MetaContact *tqparent,
+ Kopete::MetaContact *parent,
const int objectId, const int parentId, const int sequence );
~GroupWiseContact();
@@ -59,13 +59,13 @@ public:
* @param account The GroupWiseAccount this belongs to.
* @param uniqueName The userId for this contact. May be a DN, in which case it will be converted to dotted format for the contactId and stored.
- * @param tqparent The Kopete::MetaContact this contact is part of.
+ * @param parent The Kopete::MetaContact this contact is part of.
* @param objectId The contact's numeric object ID.